@@ -690,6 +690,8 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.subvs_data = None
         self.subvs_entries = []
         self.real_servers = []
+        self._waf = False
+        self._waf_params = ['alertthreshold', 'intercept']
         if not is_sub_vs:
             # Skip validation when it is a subvs as they do not have ip/port
             self.vs = ip_or_index
@@ -722,6 +724,14 @@ class VirtualService(HttpClient, KempBaseObjectModel):
             return 'Virtual Service {} {}:{} on LoadMaster {}'.format(
                 self.prot.upper(), self.vs, self.port, self.ip_address)
 
+    def to_api_dict(self):
+        api = super(VirtualService, self).to_api_dict()
+        if not self._waf:
+            for key, value in api.items():
+                if key in self._waf_params:
+                    del api[key]
+        return api
+
     def _get_base_parameters(self):
         """Returns the bare minimum VS parameters. IP, port and protocol"""
         if self.index is None:
@@ -844,7 +854,6 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.idletime = service.get('Idletime', None)
         self.mastervsid = service.get('MasterVSID', None)
 
-        self.alertthreshold = service.get('AlertThreshold', None)
         self.querytag = service.get('QueryTag', None)
         self.serverinit = service.get('ServerInit', None)
         self.addvia = service.get('AddVia', None)
@@ -858,7 +867,14 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.errorurl = service.get('ErrorUrl', None)
         self.errorpage = service.get('ErrorPage', None)
 
+        # WAF
+        self.alertthreshold = service.get('AlertThreshold', None)
         self.intercept = service.get('Intercept', None)
+        if self.alertthreshold is None:
+            self._waf = False
+        else:
+            self._waf = True
+
         self.multiconnect = service.get('MultiConnect', None)
         self.verify = service.get('Verify', None)
         self.espenabled = service.get('EspEnabled', None)
